@@ -2,9 +2,17 @@
 import os
 
 def main():
+    print("Adding RubyMine GUS Integration Tools")
+    print("If RubyMine is open, close it and run this command again")
     
     home = os.path.expanduser("~")
-    tools = "{}/Library/Preferences/RubyMine60/tools/GUS.xml".format(home)
+    
+    rubydir = "{}/Library/Preferences/RubyMine60".format(home)
+    if not os.path.exists(rubydir):
+        rubydir = "{}/Library/Preferences/RubyMine50".format(home)
+        print("You might want to upgrade to RubyMine 6.0...")
+    
+    tools = "{}/tools/GUS.xml".format(rubydir)
     
     path = os.path.dirname(os.path.realpath(__file__))
     
@@ -59,5 +67,7 @@ def main():
         tool_file.write(data)
         tool_file.close()
         
+    print("Done. Open RubyMine and Check out the GUS menu under 'Tools' or on Right Click.")
+        
 if __name__ == '__main__':
     main()
\ No newline at end of file
